@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 =encoding utf-8
 
@@ -12,6 +12,10 @@ App::Greple::xlate - translation support module for greple
 
     greple -Mxlate::deepl --xlate pattern target-file
 
+=head1 VERSION
+
+Version 0.13
+
 =head1 DESCRIPTION
 
 B<Greple> B<xlate> module find text blocks and replace them by the
@@ -269,6 +273,7 @@ it under the same terms as Perl itself.
 use v5.14;
 use warnings;
 
+use open IO => ':utf8', ':std';
 use Data::Dumper;
 
 use JSON;
